# [Zope-tests] OK : Zope Buildbot / zope2.13_win-py2.6 slave-win

jdriessen at thehealthagency.com jdriessen at thehealthagency.com
Tue Feb 1 00:14:47 EST 2011

- Next message: [Zope-tests] OK : Zope Buildbot / zope2.13_win-py2.7 slave-win
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    OK : Zope Buildbot / zope2.13_win-py2.6 slave-win
    Build: http://dev.thehealthagency.com/buildbot/builders/zope2.13_win-py2.6%20slave-win/builds/125

    Build Reason: The Periodic scheduler named 'Periodic scheduler for zope2.13_win-py2.6' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://dev.thehealthagency.com/buildbot/

- Next message: [Zope-tests] OK : Zope Buildbot / zope2.13_win-py2.7 slave-win
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list